package org.sadigit.boundary.v1.endpoint;

import io.smallrye.mutiny.Uni;
import jakarta.inject.Inject;
import jakarta.ws.rs.POST;
import jakarta.ws.rs.Path;
import jakarta.ws.rs.Produces;
import jakarta.ws.rs.QueryParam;
import jakarta.ws.rs.core.MediaType;
import jakarta.ws.rs.core.Response;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;

import java.io.InputStream;
import java.util.HashMap;
import java.util.Map;
import java.io.UnsupportedEncodingException;
import org.sadigit.model.ResponseModelIntegKeluhanMobile;
import org.sadigit.model.ResponseModelIntegKeluhanMobileTanpaOutData;
import org.sadigit.service.api.v1.GetDataPerUnitService;
import org.sadigit.service.api.v1.IssueTypeService;
import org.sadigit.service.api.v1.LoginService;
import org.sadigit.service.api.v1.PenggunaService;
import org.sadigit.service.api.v1.UnitService;
import org.sadigit.util.AppException;

@Path("api/apkt/integkeluhanmobile")
@Produces(MediaType.APPLICATION_JSON)
@Slf4j

@RequiredArgsConstructor

public class IntegKeluhanMobileResource {

    @Inject
    private final LoginService loginService;
    private final PenggunaService penggunaService;
    private final UnitService unitService;
    private final IssueTypeService issueTypeService;
    private final GetDataPerUnitService getDataPerUnitService;

    @POST
    @Path("/p00_login")
    public Response p00_login(
            @QueryParam(value = "IN_USER") String IN_USER,
            @QueryParam(value = "IN_PASSWORD") String IN_PASSWORD) throws UnsupportedEncodingException {

        ResponseModelIntegKeluhanMobile mapResponse = new ResponseModelIntegKeluhanMobile();

        // replace space with +
        IN_USER = IN_USER.replace(" ", "+");
        IN_PASSWORD = IN_PASSWORD.replace(" ", "+");

        try {
            mapResponse.setData(loginService.auth(IN_USER, IN_PASSWORD));
            mapResponse.setMessage("SUKSES");
            mapResponse.setRc("0");

        } catch (AppException e) {
            mapResponse.setMessage(e.getMessage());
            mapResponse.setRc(e.getRc());
        }

        return Response.ok(mapResponse).build();

    }

    @POST
    @Path("/P00_GET_USER")
    public Response P00_GET_USER(
            @QueryParam(value = "IN_UNITID") Long IN_UNITID,
            @QueryParam(value = "IN_POSITIONID") Long IN_POSITIONID) {

        ResponseModelIntegKeluhanMobile mapResponse = new ResponseModelIntegKeluhanMobile();

        try {
            mapResponse.setData(penggunaService.findDataPengguna(IN_UNITID, IN_POSITIONID));
            mapResponse.setMessage("SUKSES");
            mapResponse.setRc("0");

        } catch (AppException e) {
            mapResponse.setMessage(e.getMessage());
            mapResponse.setRc(e.getRc());
        }

        return Response.ok(mapResponse).build();

    }

    @POST
    @Path("/p01_getdataperunit")
    public Response p01_getdataperunit(
            @QueryParam(value = "IN_UNIT") Long IN_UNIT,
            @QueryParam(value = "IN_TGLAWAL") String IN_TGLAWAL,
            @QueryParam(value = "IN_TGLAKHIR") String IN_TGLAKHIR) {

        ResponseModelIntegKeluhanMobile mapResponse = new ResponseModelIntegKeluhanMobile();
        try {
            mapResponse.setData(getDataPerUnitService.getDataPerUnit(IN_UNIT, IN_TGLAWAL, IN_TGLAKHIR));
            mapResponse.setMessage("SUKSES");
            mapResponse.setRc("0");

        } catch (AppException e) {
            mapResponse.setMessage(e.getMessage());
            mapResponse.setRc(e.getRc());
        }

        return Response.ok(mapResponse).build();

    }

    @POST
    @Path("/p02_getdataperpetugas")
    public Response p02_getdataperpetugas(
            @QueryParam(value = "IN_UNIT") String IN_UNIT,
            @QueryParam(value = "IN_USER") String IN_USER,
            @QueryParam(value = "IN_TGLAWAL") String IN_TGLAWAL,
            @QueryParam(value = "IN_TGLAKHIR") String IN_TGLAKHIR) {

        ResponseModelIntegKeluhanMobile mapResponse = new ResponseModelIntegKeluhanMobile();
        Map<String, Object> mapResult;
        Map<String, Object> mapParam = new HashMap<>();

        try {
            mapParam.put("IN_UNIT", IN_UNIT);
            mapParam.put("IN_USER", IN_USER);
            mapParam.put("IN_TGLAWAL", IN_TGLAWAL);
            mapParam.put("IN_TGLAKHIR", IN_TGLAKHIR);

            mapParam.put("OUT_RC", "VARCHAR");
            mapParam.put("OUT_MESSAGE", "VARCHAR");
            mapParam.put("OUT_DATA", "CURSOR");

            // mapResult = IntegKeluhanMobileService.p02_getdataperpetugas(mapParam);
            // mapResponse = AppServerIntegKeluhanMobile.setResultMessage(mapResult);
            // log.info("log : {}",mapResponse);

        } catch (Exception e) {
            // log.error(e.getMessage(), e);
            mapResponse.setMessage(e.getMessage());
            // mapResponse.setRc("06");
        }

        return Response.ok(mapResponse).build();

    }

    @POST
    @Path("/p03_getpenjelasanbidang")
    public Response p03_getpenjelasanbidang(
            @QueryParam(value = "IN_LAPORAN") String IN_LAPORAN) {

        ResponseModelIntegKeluhanMobile mapResponse = new ResponseModelIntegKeluhanMobile();
        Map<String, Object> mapResult;
        Map<String, Object> mapParam = new HashMap<>();

        try {
            mapParam.put("IN_LAPORAN", IN_LAPORAN);

            mapParam.put("OUT_RC", "VARCHAR");
            mapParam.put("OUT_MESSAGE", "VARCHAR");
            mapParam.put("OUT_DATA", "CURSOR");

            // mapResult = IntegKeluhanMobileService.p03_getpenjelasanbidang(mapParam);
            // mapResponse = AppServerIntegKeluhanMobile.setResultMessage(mapResult);
            // log.info("log : {}",mapResponse);

        } catch (Exception e) {
            // log.error(e.getMessage(), e);
            mapResponse.setMessage(e.getMessage());
            // mapResponse.setRc("06");
        }

        return Response.ok(mapResponse).build();

    }

    @POST
    @Path("/p04_setpetugasbidang")
    public Response p04_setpetugasbidang(
            @QueryParam(value = "IN_REPORTNUMBER") String IN_REPORTNUMBER,
            @QueryParam(value = "IN_USER") String IN_USER,
            @QueryParam(value = "IN_FUNGSI") String IN_FUNGSI) {

        ResponseModelIntegKeluhanMobile mapResponse = new ResponseModelIntegKeluhanMobile();
        Map<String, Object> mapResult;
        Map<String, Object> mapParam = new HashMap<>();

        try {
            mapParam.put("IN_REPORTNUMBER", IN_REPORTNUMBER);
            mapParam.put("IN_USER", IN_USER);
            mapParam.put("IN_FUNGSI", IN_FUNGSI);

            mapParam.put("OUT_RC", "VARCHAR");
            mapParam.put("OUT_MESSAGE", "VARCHAR");
            mapParam.put("OUT_DATA", "CURSOR");

            // mapResult = IntegKeluhanMobileService.p04_setpetugasbidang(mapParam);
            // mapResponse = AppServerIntegKeluhanMobile.setResultMessage(mapResult);
            // log.info("log : {}",mapResponse);

        } catch (Exception e) {
            // log.error(e.getMessage(), e);
            mapResponse.setMessage(e.getMessage());
            // mapResponse.setRc("06");
        }

        return Response.ok(mapResponse).build();

    }

    @POST //
    @Path("/p05_setalihunit")
    public Response p05_setalihunit(
            @QueryParam(value = "IN_REPORTNUMBER") String IN_REPORTNUMBER,
            @QueryParam(value = "IN_USERID") String IN_USERID,
            @QueryParam(value = "IN_UNITID") String IN_UNITID) {

        ResponseModelIntegKeluhanMobileTanpaOutData mapResponse = new ResponseModelIntegKeluhanMobileTanpaOutData();
        Map<String, Object> mapResult;
        Map<String, Object> mapParam = new HashMap<>();

        try {
            mapParam.put("IN_REPORTNUMBER", IN_REPORTNUMBER);
            mapParam.put("IN_USERID", IN_USERID);
            mapParam.put("IN_UNITID", IN_UNITID);

            mapParam.put("OUT_RC", "VARCHAR");
            mapParam.put("OUT_MESSAGE", "VARCHAR");
            mapParam.put("OUT_DATA", "CURSOR");

            // mapResult = IntegKeluhanMobileService.p05_setalihunit(mapParam);
            // AppServerIntegKeluhanMobileLoginTanpaOutData.setResultMessage(mapResult);
            // log.info("log : {}",mapResponse);

        } catch (Exception e) {
            // log.error(e.getMessage(), e);
            mapResponse.setMessage(e.getMessage());
            // mapResponse.setRc("06");
        }

        return Response.ok(mapResponse).build();

    }

    @POST
    @Path("/p06_setalihbidang")
    public Response p06_setalihbidang(
            @QueryParam(value = "IN_REPORTNUMBER") String IN_REPORTNUMBER,
            @QueryParam(value = "IN_USERID") String IN_USERID,
            @QueryParam(value = "IN_FUNGSI") String IN_FUNGSI) {

        ResponseModelIntegKeluhanMobileTanpaOutData mapResponse = new ResponseModelIntegKeluhanMobileTanpaOutData();
        Map<String, Object> mapResult;
        Map<String, Object> mapParam = new HashMap<>();

        try {
            mapParam.put("IN_REPORTNUMBER", IN_REPORTNUMBER);
            mapParam.put("IN_USERID", IN_USERID);
            mapParam.put("IN_FUNGSI", IN_FUNGSI);

            mapParam.put("OUT_RC", "VARCHAR");
            mapParam.put("OUT_MESSAGE", "VARCHAR");
            mapParam.put("OUT_DATA", "CURSOR");

            // mapResult = IntegKeluhanMobileService.p06_setalihbidang(mapParam);
            // mapResponse =
            // AppServerIntegKeluhanMobileLoginTanpaOutData.setResultMessage(mapResult);
            // log.info("log : {}",mapResponse);

        } catch (Exception e) {
            // log.error(e.getMessage(), e);
            mapResponse.setMessage(e.getMessage());
            // mapResponse.setRc("06");
        }

        return Response.ok(mapResponse).build();

    }

    @POST //
    @Path("/p07_setpenjelasanbidang")
    public Response p07_setpenjelasanbidang(
            @QueryParam(value = "IN_REPORTNUMBER") String IN_REPORTNUMBER,
            @QueryParam(value = "IN_USER") String IN_USER,
            @QueryParam(value = "IN_CUSTOMERRESPONSE") String IN_CUSTOMERRESPONSE,
            @QueryParam(value = "IN_REMARK") String IN_REMARK,
            @QueryParam(value = "IN_IMPLEMENTOR") String IN_IMPLEMENTOR) {

        ResponseModelIntegKeluhanMobile mapResponse = new ResponseModelIntegKeluhanMobile();
        Map<String, Object> mapResult;
        Map<String, Object> mapParam = new HashMap<>();

        try {
            mapParam.put("IN_REPORTNUMBER", IN_REPORTNUMBER);
            mapParam.put("IN_USER", IN_USER);
            mapParam.put("IN_CUSTOMERRESPONSE", IN_CUSTOMERRESPONSE);
            mapParam.put("IN_REMARK", IN_REMARK);
            mapParam.put("IN_IMPLEMENTOR", IN_IMPLEMENTOR);

            mapParam.put("OUT_RC", "VARCHAR");
            mapParam.put("OUT_MESSAGE", "VARCHAR");
            mapParam.put("OUT_DATA", "CURSOR");

            // mapResult = IntegKeluhanMobileService.p07_setpenjelasanbidang(mapParam);
            // mapResponse = AppServerIntegKeluhanMobile.setResultMessage(mapResult);
            // log.info("log : {}",mapResponse);

        } catch (Exception e) {
            // log.error(e.getMessage(), e);
            mapResponse.setMessage(e.getMessage());
            // mapResponse.setRc("06");
        }

        return Response.ok(mapResponse).build();

    }

    @POST //
    @Path("/p08_setkonfirmasi")
    public Response p08_setkonfirmasi(
            @QueryParam(value = "IN_REPORTNUMBER") String IN_REPORTNUMBER,
            @QueryParam(value = "IN_USER") String IN_USER) {

        ResponseModelIntegKeluhanMobile mapResponse = new ResponseModelIntegKeluhanMobile();
        Map<String, Object> mapResult;
        Map<String, Object> mapParam = new HashMap<>();

        try {
            mapParam.put("IN_REPORTNUMBER", IN_REPORTNUMBER);
            mapParam.put("IN_USER", IN_USER);

            mapParam.put("OUT_RC", "VARCHAR");
            mapParam.put("OUT_MESSAGE", "VARCHAR");
            mapParam.put("OUT_DATA", "CURSOR");

            // mapResult = IntegKeluhanMobileService.p08_setkonfirmasi(mapParam);
            // mapResponse = AppServerIntegKeluhanMobile.setResultMessage(mapResult);
            // log.info("log : {}",mapResponse);

        } catch (Exception e) {
            // log.error(e.getMessage(), e);
            mapResponse.setMessage(e.getMessage());
            // mapResponse.setRc("06");
        }

        return Response.ok(mapResponse).build();

    }

    @POST //
    @Path("/p09_setselesai")
    public Response p09_setselesai(
            @QueryParam(value = "IN_REPORTNUMBER") String IN_REPORTNUMBER,
            @QueryParam(value = "IN_USER") String IN_USER) {

        ResponseModelIntegKeluhanMobile mapResponse = new ResponseModelIntegKeluhanMobile();
        Map<String, Object> mapResult;
        Map<String, Object> mapParam = new HashMap<>();

        try {
            mapParam.put("IN_REPORTNUMBER", IN_REPORTNUMBER);
            mapParam.put("IN_USER", IN_USER);

            mapParam.put("OUT_RC", "VARCHAR");
            mapParam.put("OUT_MESSAGE", "VARCHAR");

            // mapResult = IntegKeluhanMobileService.p09_setselesai(mapParam);
            // mapResponse = AppServerIntegKeluhanMobile.setResultMessage(mapResult);
            // log.info("log : {}",mapResponse);

        } catch (Exception e) {
            // log.error(e.getMessage(), e);
            mapResponse.setMessage(e.getMessage());
            // mapResponse.setRc("06");
        }

        return Response.ok(mapResponse).build();

    }

    @POST //
    @Path("/p10_setbatal")
    public Response p10_setbatal(
            @QueryParam(value = "IN_LAPORAN") String IN_LAPORAN,
            @QueryParam(value = "IN_USER") String IN_USER) {

        ResponseModelIntegKeluhanMobileTanpaOutData mapResponse = new ResponseModelIntegKeluhanMobileTanpaOutData();
        Map<String, Object> mapResult;
        Map<String, Object> mapParam = new HashMap<>();

        try {
            mapParam.put("IN_LAPORAN", IN_LAPORAN);
            mapParam.put("IN_USER", IN_USER);

            mapParam.put("OUT_RC", "VARCHAR");
            mapParam.put("OUT_MESSAGE", "VARCHAR");

            // mapResult = IntegKeluhanMobileService.p10_setbatal(mapParam);
            // mapResponse =
            // AppServerIntegKeluhanMobileLoginTanpaOutData.setResultMessage(mapResult);
            // log.info("log : {}",mapResponse);

        } catch (Exception e) {
            // log.error(e.getMessage(), e);
            mapResponse.setMessage(e.getMessage());
            // mapResponse.setRc("06");
        }

        return Response.ok(mapResponse).build();

    }

    @POST
    @Path("/P11_GETHISTRUNTASK")
    public Response P11_GETHISTRUNTASK(
            @QueryParam(value = "IN_REPORTNUMBER") String IN_REPORTNUMBER,
            @QueryParam(value = "IN_USER") String IN_USER) {

        ResponseModelIntegKeluhanMobile mapResponse = new ResponseModelIntegKeluhanMobile();
        Map<String, Object> mapResult;
        Map<String, Object> mapParam = new HashMap<>();

        try {
            mapParam.put("IN_REPORTNUMBER", IN_REPORTNUMBER);
            mapParam.put("IN_USER", IN_USER);

            mapParam.put("OUT_RC", "VARCHAR");
            mapParam.put("OUT_MESSAGE", "VARCHAR");
            mapParam.put("OUT_DATA", "CURSOR");

            // mapResult = IntegKeluhanMobileService.P11_GETHISTRUNTASK(mapParam);
            // mapResponse = AppServerIntegKeluhanMobile.setResultMessage(mapResult);
            // log.info("log : {}",mapResponse);

        } catch (Exception e) {
            // log.error(e.getMessage(), e);
            mapResponse.setMessage(e.getMessage());
            // mapResponse.setRc("06");
        }

        return Response.ok(mapResponse).build();

    }

    @POST
    @Path("/P12_GETFUNGSI")
    public Response P12_GETFUNGSI(
            @QueryParam(value = "IN_UNIT") String IN_UNIT,
            @QueryParam(value = "IN_USER") String IN_USER) {

        ResponseModelIntegKeluhanMobile mapResponse = new ResponseModelIntegKeluhanMobile();
        Map<String, Object> mapResult;
        Map<String, Object> mapParam = new HashMap<>();

        try {
            mapParam.put("IN_UNIT", IN_UNIT);
            mapParam.put("IN_USER", IN_USER);

            mapParam.put("OUT_RC", "VARCHAR");
            mapParam.put("OUT_MESSAGE", "VARCHAR");
            mapParam.put("OUT_DATA", "CURSOR");

            // mapResult = IntegKeluhanMobileService.P12_GETFUNGSI(mapParam);
            // mapResponse = AppServerIntegKeluhanMobile.setResultMessage(mapResult);
            // log.info("log : {}",mapResponse);

        } catch (Exception e) {
            // log.error(e.getMessage(), e);
            mapResponse.setMessage(e.getMessage());
            // mapResponse.setRc("06");
        }

        return Response.ok(mapResponse).build();

    }

    @POST
    @Path("/P13_GETMASTER_ISSUETYPE")
    public Response P13_GETMASTER_ISSUETYPE() {

        ResponseModelIntegKeluhanMobile mapResponse = new ResponseModelIntegKeluhanMobile();

        try {
            mapResponse.setData(issueTypeService.findAll());
            mapResponse.setMessage("SUKSES");
            mapResponse.setRc("00");

        } catch (AppException e) {
            mapResponse.setMessage(e.getMessage());
            mapResponse.setRc(e.getRc());
        }

        return Response.ok(mapResponse).build();

    }

    @POST
    @Path("/P14_GETUNIT")
    public Response P14_GETUNIT(
            @QueryParam(value = "IN_UNITTYPEID") Long IN_UNITTYPEID) {

        ResponseModelIntegKeluhanMobile mapResponse = new ResponseModelIntegKeluhanMobile();

        try {
            mapResponse.setData(unitService.findByUnitTypeId(IN_UNITTYPEID));
            mapResponse.setMessage("SUKSES");
            mapResponse.setRc("00");

        } catch (AppException e) {
            mapResponse.setMessage(e.getMessage());
            mapResponse.setRc(e.getRc());
        }

        return Response.ok(mapResponse).build();

    }

    @POST
    @Path("/P15_GETJMLKELUHAN")
    public Response P15_GETJMLKELUHAN(
            @QueryParam(value = "IN_DISTRIBUTION") String IN_DISTRIBUTION,
            @QueryParam(value = "IN_CREATEDATE") String IN_CREATEDATE,
            @QueryParam(value = "IN_ESCALATIONID") String IN_ESCALATIONID) {

        ResponseModelIntegKeluhanMobile mapResponse = new ResponseModelIntegKeluhanMobile();
        Map<String, Object> mapResult;
        Map<String, Object> mapParam = new HashMap<>();

        try {
            mapParam.put("IN_DISTRIBUTION", IN_DISTRIBUTION);
            mapParam.put("IN_CREATEDATE", IN_CREATEDATE);
            mapParam.put("IN_ESCALATIONID", IN_ESCALATIONID);
            // mapParam.put("IN_USER", IN_USER);

            mapParam.put("OUT_RC", "VARCHAR");
            mapParam.put("OUT_MESSAGE", "VARCHAR");
            mapParam.put("OUT_DATA", "CURSOR");

            // mapResult = IntegKeluhanMobileService.P15_GETJMLKELUHAN(mapParam);
            // mapResponse = AppServerIntegKeluhanMobile.setResultMessage(mapResult);
            // log.info("log : {}",mapResponse);

        } catch (Exception e) {
            // log.error(e.getMessage(), e);
            mapResponse.setMessage(e.getMessage());
            // mapResponse.setRc("06");
        }

        return Response.ok(mapResponse).build();

    }

    @POST
    @Path("/P16_GETBIDANGMEMBER")
    public Response P16_GETBIDANGMEMBER(
            @QueryParam(value = "IN_BIDANGUNITID") Long IN_BIDANGUNITID) {

        ResponseModelIntegKeluhanMobile mapResponse = new ResponseModelIntegKeluhanMobile();
        Map<String, Object> mapResult;
        Map<String, Object> mapParam = new HashMap<>();

        try {
            mapParam.put("IN_BIDANGUNITID", IN_BIDANGUNITID);

            mapParam.put("OUT_RC", "VARCHAR");
            mapParam.put("OUT_MESSAGE", "VARCHAR");
            mapParam.put("OUT_DATA", "CURSOR");

            // mapResult = IntegKeluhanMobileService.P16_GETBIDANGMEMBER(mapParam);
            // mapResponse = AppServerIntegKeluhanMobile.setResultMessage(mapResult);
            // log.info("log : {}",mapResponse);

        } catch (Exception e) {
            // log.error(e.getMessage(), e);
            mapResponse.setMessage(e.getMessage());
            // mapResponse.setRc("06");
        }

        return Response.ok(mapResponse).build();

    }

    @POST
    @Path("/P17_VALIDASIEMAIL")
    public Response P17_VALIDASIEMAIL(
            @QueryParam(value = "IN_EMAIL") String IN_EMAIL) {

        ResponseModelIntegKeluhanMobile mapResponse = new ResponseModelIntegKeluhanMobile();
        Map<String, Object> mapResult;
        Map<String, Object> mapParam = new HashMap<>();

        try {
            mapParam.put("IN_EMAIL", IN_EMAIL);

            mapParam.put("OUT_RC", "VARCHAR");
            mapParam.put("OUT_MESSAGE", "VARCHAR");
            mapParam.put("OUT_DATA", "CURSOR");

            // mapResult = IntegKeluhanMobileService.P17_VALIDASIEMAIL(mapParam);
            // mapResponse = AppServerIntegKeluhanMobile.setResultMessage(mapResult);
            // log.info("log : {}",mapResponse);

        } catch (Exception e) {
            // log.error(e.getMessage(), e);
            mapResponse.setMessage(e.getMessage());
            // mapResponse.setRc("06");
        }

        return Response.ok(mapResponse).build();

    }

    @POST
    @Path("/P18_ISSUETYPE")
    public Response P18_ISSUETYPE(
    // @QueryParam(value = "IN_UNIT") String IN_UNIT,
    // @QueryParam(value = "IN_USER") String IN_USE
    ) {

        ResponseModelIntegKeluhanMobile mapResponse = new ResponseModelIntegKeluhanMobile();

        try {
            mapResponse.setData(issueTypeService.findActive());
            mapResponse.setMessage("SUKSES");
            mapResponse.setRc("00");

        } catch (AppException e) {
            mapResponse.setMessage(e.getMessage());
            mapResponse.setRc(e.getRc());
        }

        return Response.ok(mapResponse).build();

    }

    @POST
    @Path("/P19_SUBISSUETYPE")
    public Response P19_SUBISSUETYPE(
    // @QueryParam(value = "IN_UNIT") String IN_UNIT,
    // @QueryParam(value = "IN_USER") String IN_USE
    ) {

        ResponseModelIntegKeluhanMobile mapResponse = new ResponseModelIntegKeluhanMobile();
        Map<String, Object> mapResult;
        Map<String, Object> mapParam = new HashMap<>();

        try {
            // mapParam.put("IN_UNIT", IN_UNIT);
            // mapParam.put("IN_USER", IN_USER);

            mapParam.put("OUT_RC", "VARCHAR");
            mapParam.put("OUT_MESSAGE", "VARCHAR");
            mapParam.put("OUT_DATA", "CURSOR");

            // mapResult = IntegKeluhanMobileService.P19_SUBISSUETYPE(mapParam);
            // mapResponse = AppServerIntegKeluhanMobile.setResultMessage(mapResult);
            // log.info("log : {}",mapResponse);

        } catch (Exception e) {
            // log.error(e.getMessage(), e);
            mapResponse.setMessage(e.getMessage());
            // mapResponse.setRc("06");
        }

        return Response.ok(mapResponse).build();

    }
}
