package org.sadigit.control.errorhandler;

import java.util.Map;
import java.util.stream.Collectors;

import jakarta.validation.ConstraintViolationException;
import jakarta.ws.rs.core.Response;
import jakarta.ws.rs.ext.ExceptionMapper;
import jakarta.ws.rs.ext.Provider;
import lombok.extern.slf4j.Slf4j;

@Provider
@Slf4j
public class ValidationExceptionErrorHandler implements ExceptionMapper<ConstraintViolationException>{

    @Override
    public Response toResponse(ConstraintViolationException exception) {
        
        var errorStructure = exception.getConstraintViolations()
            .stream()
            .map(violation -> Map.of(
                "path", violation.getPropertyPath().toString(),
                "message", violation.getMessage()
            ))
            .collect(Collectors.toList());

        log.error("Validation error: {}", errorStructure);
        return Response.status(Response.Status.OK).entity(errorStructure).build();
    }
    
}
